/*
 * This file is part of Vestige.
 *
 * Vestige is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Vestige is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Vestige.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.apache.sshd.common.signature;

import org.apache.sshd.common.NamedFactory;
import org.apache.sshd.common.Signature;

public class SignatureRSASHA256 extends AbstractSignature {

    /**
     * A named factory for RSA <code>Signature</code>
     */
    public static class Factory implements NamedFactory<Signature> {

        public String getName() {
            return "rsa-sha2-256";
        }

        public Signature create() {
            return new SignatureRSASHA256();
        }

    }

    public SignatureRSASHA256() {
        super("SHA256withRSA", "rsa-sha2-256");
    }

    public byte[] sign() throws Exception {
        return signature.sign();
    }

    public boolean verify(byte[] sig) throws Exception {
        sig = extractSig(sig);
        return signature.verify(sig);
    }

}
